#!/usr/bin/env perl

# Traverse the current directory for MP3 files
# If an MP3 file does not have a ID3v1 tag then create one from the ID3v2 tag
# If an MP3 file does not have a ID3v2 tag then create one from the ID3v1 tag
# MP3 files with neither tag should be processed with some other tagging program

use MP3::Tag;

opendir(DIR, ".") or die "can't open current directory: $!";
my @files = grep { /\.mp3$/i } readdir(DIR);
foreach $mp3 (@files) {
	populate_mp3($mp3);
}

sub populate_mp3 {
	my $filename = shift(@_);
	
	my $mp3 = MP3::Tag->new($filename);

	($title, $track, $artist, $album, $comment, $year, $genre) = $mp3->autoinfo();

# 	print "From autoinfo:\nTitle: ", $title, "\nTrack: ", $track, "\nArtist: ", $artist, "\nAlbum: ", $album, "\nComment: ", $comment, "\nYear: ", $year, "\nGenre: ", $genre, "\n";
	print $filename;

	@tags = $mp3->get_tags();

	if (exists $mp3->{ID3v1}) {
		print "\tID3v1 exists";
	} else {
		print "\tID3v1 created";
		my $ID3v1_title = substr $title, 0, 30;
		my $ID3v1_artist = substr $artist, 0, 30;
		my $ID3v1_album = substr $album, 0, 30;
		my $ID3v1_comment = substr $comment, 0, 28;
		$mp3->new_tag("ID3v1");
		$mp3->{ID3v1}->all($ID3v1_title, $ID3v1_artist, $ID3v1_album, $year, $ID3v1_comment, $track, $genre);
		$mp3->{ID3v1}->write_tag;
	}

	if (exists $mp3->{ID3v2}) {
		print "\tID3v2 exists\n";
	} else {
		print "\tID3v2 created\n";
		$mp3->new_tag("ID3v2");
		$mp3->title_set($title, TRUE);
		$mp3->track_set($track, TRUE);
		$mp3->artist_set($artist, TRUE);
		$mp3->album_set($album, TRUE);
		$mp3->comment_set($comment, TRUE);
		$mp3->year_set($year, TRUE);
		$mp3->genre_set($genre, TRUE);
		$mp3->{ID3v2}->write_tag;
	}

	$mp3->close();
}